@@ -1,4 +1,4 @@
-// $Id: BRbReadNode.cpp,v 1.55 2003/02/03 05:46:42 yuya Exp $
+// $Id: BRbReadNode.cpp,v 1.58 2003/02/10 08:15:59 yuya Exp $
 
 #ifdef BRB_READER
 
@@ -287,8 +287,9 @@ BRbReadNode::read_node()
 		}
 		case NODE_DASGN:
 		{
-			m_debug.raise("NODE_DASGN is not implemented");
-			break;
+			ID    vid   = read_id();
+			NODE* value = read_node();
+			return NEW_DASGN(vid, value);
 		}
 		case NODE_DASGN_CURR:
 		{
@@ -430,7 +431,7 @@ BRbReadNode::read_node()
 		case NODE_IASGN:
 		{
 			ID    name  = read_id();
-			NODE* value = read_node();
+			NODE* value = read_node_opt();
 			return NEW_IASGN(name, value);
 		}
 		case NODE_IF:
@@ -548,8 +549,12 @@ BRbReadNode::read_node()
 		}
 		case NODE_OP_ASGN2:
 		{
-			m_debug.raise("NODE_OP_ASGN2 is not implemented");
-			break;
+			NODE* recv  = read_node();
+			NODE* value = read_node();
+			ID    vid   = read_id();
+			ID    mid   = read_id();
+			ID    aid   = read_id();
+			return rb_node_newnode(NODE_OP_ASGN2, recv, value, rb_node_newnode(NODE_OP_ASGN2, vid, mid, aid));
 		}
 		case NODE_OP_ASGN_AND:
 		{
