@@ -1,7 +1,7 @@
 
 #==============================================================================#
 # test/testcase.rb
-# $Id: testcase.rb,v 1.9 2003/01/13 07:01:48 yuya Exp $
+# $Id: testcase.rb,v 1.10 2003/01/16 09:10:44 yuya Exp $
 #==============================================================================#
 
 require 'test/unit'
@@ -35,7 +35,7 @@ class BRbTestCase < Test::Unit::TestCase
   end
 
   def exec_bruby(file)
-    return `ruby ../bin/bruby.rb -e #{file}`
+    return `ruby ../bin/brbexe.rb #{file}`
   end
 
 end
